@@ -281,6 +281,22 @@ struct iso_write_opts {
      */
     uint32_t data_start_lba;
 
+    /**
+     * If not empty: A text holding parameters "name" and "timestamp" for
+     * a scdbackup stream checksum tag. See scdbackup/README appendix VERIFY.
+     * It makes sense only for single session images which start at LBA 0.
+     * Such a tag may be part of a libisofs checksum tag block after the
+     * session tag line. It then covers the whole session up to its own start
+     * position.
+     */
+    char scdbackup_tag_parm[100];
+
+    /* If not NULL: A pointer to an application provided array with
+       at least 512 characters. The effectively written scdbackup tag
+       will be copied to this memory location.
+     */
+    char *scdbackup_tag_written;
+
 };
 
 typedef struct ecma119_image Ecma119Image;
@@ -464,6 +480,9 @@ struct ecma119_image
            is submitted with ecma119_image_new() ?
      */
 
+    char scdbackup_tag_parm[100];
+    char *scdbackup_tag_written;
+
 #endif /* Libisofs_with_checksumS */
 
     /* Buffer for communication between burn_source and writer thread */
