@@ -18,6 +18,13 @@ struct Iso_File_Src
 {
     unsigned int prev_img :1; /**< if the file comes from a previous image */
 
+#ifdef Libisofs_with_checksumS
+
+    unsigned int checksum_index :31;
+
+#endif /* Libisofs_with_checksumS */
+
+
     /** File Sections of the file in the image */
     struct iso_file_section *sections;
     int nsections;
@@ -43,7 +50,7 @@ int iso_file_src_cmp(const void *n1, const void *n2);
  * @param src
  *      Will be filled with a pointer to the IsoFileSrc
  * @return
- *      1 on success, < 0 on error
+ *      1 if new object was created, 0 if object existed, < 0 on error
  */
 int iso_file_src_create(Ecma119Image *img, IsoFile *file, IsoFileSrc **src);
 
