@@ -115,3 +115,16 @@ IsoFilesystem* iso_file_source_get_filesystem(IsoFileSource *src)
 {
     return src->class->get_filesystem(src);
 }
+
+
+inline
+int iso_file_source_get_aa_string(IsoFileSource *src,
+                                  unsigned char **aa_string, int flag)
+{
+    if (src->class->version < 1) {
+        *aa_string = NULL;
+        return 1;
+    }
+    return src->class->get_aa_string(src, aa_string, flag);
+}
+
