@@ -148,6 +148,22 @@ struct Iso_Image
     uint8_t *used_inodes;
     ino_t used_inodes_start;
 
+#ifdef Libisofs_with_checksumS
+
+    /**
+     * Array of MD5 checksums as announced by xattr "isofs.ca" of the 
+     * root node. Array element 0 contains an overall image checksum for the
+     * block range checksum_start_lba,checksum_end_lba. Element size is
+     * 16 bytes. IsoFile objects in the image may have xattr "isofs.cx"
+     * which gives their index in checksum_array.
+     */
+    uint32_t checksum_start_lba;
+    uint32_t checksum_end_lba;
+    uint32_t checksum_idx_count;
+    char *checksum_array;
+
+#endif /* Libisofs_with_checksumS */
+
 };
 
 
@@ -181,4 +197,18 @@ ino_t img_give_ino_number(IsoImage *image, int flag);
 */
 int img_make_inos(IsoImage *image, IsoDir *dir, int flag);
 
+
+/* Free the checksum array of an image and reset its layout parameters
+*/
+int iso_image_free_checksums(IsoImage *image, int flag);
+
+
+/* Equip an ISO image with a new checksum array buffer (after isofs.ca and
+   isofs.cx have already been adjusted).
+*/
+int iso_image_set_checksums(IsoImage *image, char *checksum_array, 
+                            uint32_t start_lba, uint32_t end_lba,
+                            uint32_t idx_count, int flag);
+
+
 #endif /*LIBISO_IMAGE_H_*/
