@@ -13,6 +13,8 @@
 #include "image.h"
 #include "filesrc.h"
 #include "eltorito.h"
+#include "libisofs.h"
+
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -296,7 +298,8 @@ int joliet_create_mangled_name(uint16_t *dest, uint16_t *src, int digits,
     int ret, pos;
     uint16_t *ucsnumber;
     char fmt[16];
-    char *nstr = alloca(digits + 1);
+    char nstr[72]; /* The only caller of this function allocates dest with 66
+                      elements and limits digits to < 8 */
 
     sprintf(fmt, "%%0%dd", digits);
     sprintf(nstr, fmt, number);
@@ -372,6 +375,8 @@ int mangle_single_dir(Ecma119Image *t, JolietNode *dir)
          * A max of 7 characters is good enought, it allows handling up to
          * 9,999,999 files with same name.
          */
+         /* Important: joliet_create_mangled_name() relies on digits < 72 */
+
         while (digits < 8) {
             int ok, k;
             uint16_t *dot;
