@@ -274,6 +274,8 @@ const char *iso_error_to_msg(int errcode)
         return "Checksum tag with unexpected address range encountered";
     case ISO_MD5_STREAM_CHANGE:
         return "Detected file content changes while it was written into the image";
+    case ISO_SCDBACKUP_TAG_NOT_0:
+        return "Session does not start at LBA 0. scdbackup checksum tag not written.";
     default:
         return "Unknown error";
     }
